Documentation
¶
Overview ¶
Package belt is an opinionated collection of HTML components for shared use by multiple web apps.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Change ¶
type Change struct {
State state.Change
Title string
HTMLURL string
OnClick string // Optional.
Short bool
}
Change is a component that displays a change, with a state icon and title.
type Commit ¶
type Commit struct {
SHA string
Message string
AuthorAvatarURL string
HTMLURL string // Optional.
Short bool
}
Commit is a component that displays a commit, with an author and title.
Click to show internal directories.
Click to hide internal directories.